@@ -5,13 +5,15 @@ log = logging.getLogger(__name__)
 import copy
 import math
 import pandas as pd
-from typing import Callable, Optional, Union
+from typing import Optional, Union, Dict
 from pyform.timeseries import TimeSeries
+from pyform.returns.compound import compound, ret_to_period
+from pyform.returns.metrics import calc_ann_vol
+from pyform.util.freq import is_lower_freq, calc_samples_per_year
 
 
 class ReturnSeries(TimeSeries):
-    """A return series. It should be datetime indexed and
-       has one column of returns data.
+    """A return series that's datetime indexed and has one column of returns data
     """
 
     def __init__(self, series, name: Optional[str] = None):
@@ -26,67 +28,6 @@ class ReturnSeries(TimeSeries):
         else:
             self.name = name
 
-    @staticmethod
-    def _compound_geometric(returns: pd.Series) -> float:
-        """Performs geometric compounding.
-
-        e.g. if there are 3 returns r1, r2, r3,
-        calculate (1+r1) * (1+r2) * (1+r3) - 1
-
-        Args:
-            returns: pandas series of returns, in decimals.
-                i.e. 3% should be expressed as 0.03, not 3.
-
-        Returns:
-            float: total compounded return
-        """
-
-        return (1 + returns).prod() - 1
-
-    @staticmethod
-    def _compound_arithmetic(returns: pd.Series) -> float:
-        """Performs arithmatic compounding.
-
-        e.g. if there are 3 returns r1, r2, r3,
-        calculate ``r1 + r2`` + r3
-
-        Args:
-            returns: pandas series of returns, in decimals.
-                i.e. 3% should be expressed as 0.03, not 3.
-
-        Returns:
-            float: total compounded return
-        """
-
-        return sum(returns)
-
-    @staticmethod
-    def _compound_continuous(returns: pd.Series) -> float:
-        """Performs continuous compounding.
-
-        e.g. if there are 3 returns r1, r2, r3,
-        calculate exp(``r1 + r2`` + r3) - 1
-
-        Args:
-            returns: pandas series of returns, in decimals.
-                i.e. 3% should be expressed as 0.03, not 3.
-
-        Returns:
-            float: total compounded return
-        """
-
-        return math.exp(sum(returns)) - 1
-
-    def _compound(self, method: str) -> Callable:
-
-        compound = {
-            "arithmetic": self._compound_arithmetic,
-            "geometric": self._compound_geometric,
-            "continuous": self._compound_continuous,
-        }
-
-        return compound[method]
-
     def to_period(self, freq: str, method: str) -> pd.DataFrame:
         """Converts return series to a different (and lower) frequency.
 
@@ -103,24 +44,24 @@ class ReturnSeries(TimeSeries):
             pd.DataFrame: return series in desired frequency
         """
 
+        # Use businessness days for all return series
         if freq == "D":
-            # Use businessness days for all return series
             freq = "B"
 
+        if freq == self.freq:
+            return self.series
+
+        # make sure it's not converting to a higher frequency
+        # e.g. trying to convert a monthly series into daily
         try:
-            assert self._freq_compare(freq, self.freq)
+            assert is_lower_freq(freq, self.freq)
         except AssertionError:
             raise ValueError(
                 "Cannot convert to higher frequency. "
                 f"target={freq}, current={self.freq}"
             )
 
-        if method not in ["arithmetic", "geometric", "continuous"]:
-            raise ValueError(
-                "Method should be one of 'geometric', 'arithmetic' or 'continuous'"
-            )
-
-        return self.series.groupby(pd.Grouper(freq=freq)).agg(self._compound(method))
+        return ret_to_period(self.series, freq, method)
 
     def to_week(self, method: Optional[str] = "geometric") -> pd.DataFrame:
         """Converts return series to weekly frequency.
@@ -128,10 +69,6 @@ class ReturnSeries(TimeSeries):
         Args:
             method: compounding method. Defaults to "geometric".
 
-                * 'geometric': geometric compounding ``(1+r1) * (1+r2) - 1``
-                * 'arithmetic': arithmetic compounding ``r1 + r2``
-                * 'continuous': continous compounding ``exp(r1+r2) - 1``
-
         Returns:
             pd.DataFrame: return series, in weekly frequency
         """
@@ -144,10 +81,6 @@ class ReturnSeries(TimeSeries):
         Args:
             method: compounding method. Defaults to "geometric".
 
-                * 'geometric': geometric compounding ``(1+r1) * (1+r2) - 1``
-                * 'arithmetic': arithmetic compounding ``r1 + r2``
-                * 'continuous': continous compounding ``exp(r1+r2) - 1``
-
         Returns:
             pd.DataFrame: return series, in monthly frequency
         """
@@ -160,10 +93,6 @@ class ReturnSeries(TimeSeries):
         Args:
             method: compounding method. Defaults to "geometric".
 
-                * 'geometric': geometric compounding ``(1+r1) * (1+r2) - 1``
-                * 'arithmetic': arithmetic compounding ``r1 + r2``
-                * 'continuous': continous compounding ``exp(r1+r2) - 1``
-
         Returns:
             pd.DataFrame: return series, in quarterly frequency
         """
@@ -176,30 +105,20 @@ class ReturnSeries(TimeSeries):
         Args:
             method: compounding method. Defaults to "geometric".
 
-                * 'geometric': geometric compounding ``(1+r1) * (1+r2) - 1``
-                * 'arithmetic': arithmetic compounding ``r1 + r2``
-                * 'continuous': continous compounding ``exp(r1+r2) - 1``
-
         Returns:
             pd.DataFrame: return series, in annual frequency
         """
 
         return self.to_period("Y", method)
 
-    def _normalize_daterange(self, series: "ReturnSeries"):
+    def add_bm(self, benchmark: "ReturnSeries", name: Optional[str] = None):
+        """Adds a benchmark for the return series.
 
-        series = copy.deepcopy(series)
-        series.set_daterange(start=self.start, end=self.end)
+        A benchmark is useful and needed in order to calculate:
 
-        return series
-
-    def add_benchmark(self, benchmark: "ReturnSeries", name: Optional[str] = None):
-        """Add a benchmark for the return series. A benchmark is useful and needed
-           in order to calculate:
-
-                * 'correlation': is the correlation between the return series and
-                    the benchmark
-                * 'beta': is the CAPM beta between the return series and the benchmark
+            * 'correlation': is the correlation between the return series and
+                the benchmark
+            * 'beta': is the CAPM beta between the return series and the benchmark
 
         Args:
             benchmark: A benchmark. Should be a ReturnSeries object.
@@ -213,12 +132,12 @@ class ReturnSeries(TimeSeries):
         log.info(f"Adding benchmark. name={name}")
         self.benchmark[name] = copy.deepcopy(benchmark)
 
-    def add_risk_free(self, risk_free: "ReturnSeries", name: Optional[str] = None):
-        """Add a risk free rate for the return series. A benchmark is useful and needed
-           in order to calculate:
+    def add_rf(self, risk_free: "ReturnSeries", name: Optional[str] = None):
+        """Adds a risk free rate for the return series.
 
-                * 'sharpe ratio'
+        A risk free rate is useful and needed in order to calculate:
 
+            * 'sharpe ratio'
 
         Args:
             risk_free: A risk free rate. Should be a ReturnSeries object.
@@ -281,22 +200,22 @@ class ReturnSeries(TimeSeries):
         if not len(self.benchmark) > 0:
             raise ValueError("Correlation needs at least one benchmark.")
 
-        ret = self.to_period(freq=freq, method=compound_method)
-        n_ret = len(ret.index)
-
         # Columns in the returned dataframe
-        bm_names = []
-        corr = []
-        start = []
-        end = []
-        skipped = []
+        names, corr, start, end, used = ([] for i in range(5))
+
+        # Convert return
+        ret = self.to_period(freq=freq, method=compound_method)
 
         for name, benchmark in self.benchmark.items():
 
             try:
 
-                # Modify benchmark so it's in the same timerange as the returns series
-                benchmark = self._normalize_daterange(benchmark)
+                # keep record of start and so they can be reset later
+                bm_start = benchmark.start
+                bm_end = benchmark.end
+
+                # modify benchmark so it's in the same timerange as the returns series
+                self.align_daterange(benchmark)
 
                 # Convert benchmark to desired frequency
                 # note this is done after it's time range has been normalized
@@ -311,15 +230,15 @@ class ReturnSeries(TimeSeries):
                 corr.append(df.corr(method).iloc[0, 1])
 
                 # Add benchmark to list of benchmark names
-                bm_names.append(name)
+                names.append(name)
 
                 if meta:
-                    # Add start and end date used to compute correlation
-                    start.append(benchmark.start)
-                    end.append(benchmark.end)
+                    start.append(benchmark.start)  # start date of data used
+                    end.append(benchmark.end)  # end date of data used
+                    used.append(len(df.index))  # number of rows used in calculation
 
-                    # Add number of rows skipped in calculation
-                    skipped.append(n_ret - len(df.index))
+                # Reset bm daterange
+                benchmark.set_daterange(bm_start, bm_end)
 
             except Exception as e:  # pragma: no cover
 
@@ -330,33 +249,33 @@ class ReturnSeries(TimeSeries):
 
             result = pd.DataFrame(
                 data={
-                    "name": bm_names,
+                    "name": names,
                     "field": "correlation",
                     "value": corr,
                     "freq": freq,
                     "method": method,
                     "start": start,
                     "end": end,
-                    "total": n_ret,
-                    "skipped": skipped,
+                    "total": len(ret.index),
+                    "used": used,
                 }
             )
 
         else:
 
             result = pd.DataFrame(
-                data={"name": bm_names, "field": "correlation", "value": corr}
+                data={"name": names, "field": "correlation", "value": corr}
             )
 
         return result
 
-    def get_total_return(
+    def get_tot_ret(
         self,
         include_bm: Optional[bool] = True,
         method: Optional[str] = "geometric",
         meta: Optional[bool] = False,
     ) -> pd.DataFrame:
-        """Compute total return of the series
+        """Computes total return of the series
 
         Args:
             include_bm: whether to compute total return for benchmarks as well.
@@ -382,39 +301,40 @@ class ReturnSeries(TimeSeries):
         """
 
         # Columns in the returned dataframe
-        names = []
-        total_return = []
-        start = []
-        end = []
+        names, total_return, start, end = ([] for i in range(4))
 
-        names.append(self.name)
-        total_return.append(self._compound(method)(self.series.iloc[:, 0]))
-
-        if meta:
-            start.append(self.start)
-            end.append(self.end)
+        run_name = [self.name]
+        run_data = [self]
 
         if include_bm:
-            for name, benchmark in self.benchmark.items():
+            run_name += list(self.benchmark.keys())
+            run_data += list(self.benchmark.values())
 
-                try:
+        for name, series in zip(run_name, run_data):
 
-                    # Modify benchmark so it's in the same timerange as the
-                    # returns series
-                    benchmark = self._normalize_daterange(benchmark)
-                    names.append(name)
-                    total_return.append(
-                        self._compound(method)(benchmark.series.iloc[:, 0])
-                    )
+            try:
 
-                    if meta:
-                        start.append(benchmark.start)
-                        end.append(benchmark.end)
+                # keep record of start and so they can be reset later
+                series_start = series.start
+                series_end = series.end
 
-                except Exception as e:  # pragma: no cover
+                # modify series so it's in the same timerange as the main series
+                self.align_daterange(series)
+                tot_ret = compound(method)(series.series.iloc[:, 0])
 
-                    log.error(f"Cannot compute total return: benchmark={name}: {e}")
-                    pass
+                names.append(name)
+                total_return.append(tot_ret)
+
+                if meta:
+                    start.append(series.start)
+                    end.append(series.end)
+
+                series.set_daterange(series_start, series_end)
+
+            except Exception as e:  # pragma: no cover
+
+                log.error(f"Cannot compute total return: name={name}: {e}")
+                pass
 
         if meta:
 
@@ -437,13 +357,13 @@ class ReturnSeries(TimeSeries):
 
         return result
 
-    def get_annualized_return(
+    def get_ann_ret(
         self,
         method: Optional[str] = "geometric",
         include_bm: Optional[bool] = True,
         meta: Optional[bool] = False,
     ):
-        """Compute annualized return of the series
+        """Computes annualized return of the series
 
         Args:
             method: method to use when compounding return. Defaults to "geometric".
@@ -468,8 +388,7 @@ class ReturnSeries(TimeSeries):
             meta is set to True.
         """
 
-        result = self.get_total_return(method=method, include_bm=include_bm, meta=True)
-        result["field"] = "annualized return"
+        result = self.get_tot_ret(method=method, include_bm=include_bm, meta=True)
 
         # find number of days
         one_day = pd.to_timedelta(1, unit="D")
@@ -483,6 +402,8 @@ class ReturnSeries(TimeSeries):
         elif method == "continuous":
             result["value"] = (result["value"] + 1).apply(math.log) * (1 / years)
 
+        result["field"] = "annualized return"
+
         if meta:
             result = result[["name", "field", "value", "method", "start", "end"]]
         else:
@@ -490,7 +411,7 @@ class ReturnSeries(TimeSeries):
 
         return result
 
-    def get_annualized_volatility(
+    def calc_ann_vol(
         self,
         freq: Optional[str] = "M",
         include_bm: Optional[bool] = True,
@@ -498,7 +419,7 @@ class ReturnSeries(TimeSeries):
         compound_method: Optional[str] = "geometric",
         meta: Optional[bool] = False,
     ) -> pd.DataFrame:
-        """Compute annualized volatility of the series
+        """Computes annualized volatility of the series
 
         Args:
             freq: Returns are converted to the same frequency before volatility
@@ -529,64 +450,47 @@ class ReturnSeries(TimeSeries):
             meta is set to True.
         """
 
-        # delta degrees of freedom, used for calculate standard deviation
-        ddof = {"sample": 1, "population": 0}[method]
-
         # Columns in the returned dataframe
-        names = []
-        ann_vol = []
-        start = []
-        end = []
+        names, ann_vol, start, end = ([] for i in range(4))
 
-        # Convert series to the desired frequency
-        ret = self.to_period(freq=freq, method=compound_method)
-
-        # To annualize, after changing the frequency, see how many
-        # periods there are in a year
-        one_year = pd.to_timedelta(365.25, unit="D")
-        years = (self.end - self.start) / one_year
-        sample_per_year = len(ret.index) / years
-
-        vol = ret.iloc[:, 0].std(ddof=ddof)
-        vol *= math.sqrt(sample_per_year)
-
-        names.append(ret.columns[0])
-        ann_vol.append(vol)
-
-        if meta:
-            start.append(self.start)
-            end.append(self.end)
+        run_name = [self.name]
+        run_data = [self]
 
         if include_bm:
-            for name, benchmark in self.benchmark.items():
+            run_name += list(self.benchmark.keys())
+            run_data += list(self.benchmark.values())
 
-                try:
+        for name, series in zip(run_name, run_data):
 
-                    # Modify benchmark so it's in the same timerange as the
-                    # returns series
-                    benchmark = self._normalize_daterange(benchmark)
-                    bm = benchmark.to_period(freq=freq, method=compound_method)
+            try:
 
-                    years = (benchmark.end - benchmark.start) / one_year
-                    sample_per_year = len(bm.index) / years
+                # keep record of start and so they can be reset later
+                series_start = series.start
+                series_end = series.end
 
-                    vol = bm.iloc[:, 0].std(ddof=ddof)
-                    vol *= math.sqrt(sample_per_year)
+                # modify series so it's in the same timerange as the main series
+                self.align_daterange(series)
 
-                    names.append(name)
-                    ann_vol.append(vol)
+                # Convert return to desired frequency
+                ret = series.to_period(freq=freq, method=compound_method)
+                samples_per_year = calc_samples_per_year(
+                    len(ret.index), series.start, series.end
+                )
+                vol = calc_ann_vol(ret, method, samples_per_year)
 
-                    if meta:
-                        start.append(benchmark.start)
-                        end.append(benchmark.end)
+                names.append(name)
+                ann_vol.append(vol)
 
-                except Exception as e:  # pragma: no cover
+                if meta:
+                    start.append(series.start)
+                    end.append(series.end)
 
-                    log.error(
-                        "Cannot compute annualized volatility: "
-                        f"benchmark={name}: {e}"
-                    )
-                    pass
+                series.set_daterange(series_start, series_end)
+
+            except Exception as e:  # pragma: no cover
+
+                log.error(f"Cannot compute annualized volatility: name={name}: {e}")
+                pass
 
         if meta:
 
@@ -610,7 +514,7 @@ class ReturnSeries(TimeSeries):
 
         return result
 
-    def get_sharpe_ratio(
+    def get_sharpe(
         self,
         freq: Optional[str] = "M",
         risk_free: Optional[Union[float, int, str]] = 0,
@@ -618,7 +522,7 @@ class ReturnSeries(TimeSeries):
         compound_method: Optional[str] = "geometric",
         meta: Optional[bool] = False,
     ) -> pd.DataFrame:
-        """Compute Sharpe ratio of the series
+        """Computes Sharpe ratio of the series
 
         Args:
             freq: Returns are converted to the same frequency before Sharpe ratio
@@ -628,7 +532,7 @@ class ReturnSeries(TimeSeries):
                 in decimals. i.e. 1% annual cash return will be entered as
                 ``annualized_return=0.01``. If is string, look for the corresponding
                 DataFrame of risk free rate in ``self.risk_free``. ``self.risk_free``
-                can be set via the ``add_risk_free()`` class method. Defaults to 0.
+                can be set via the ``add_rf()`` class method. Defaults to 0.
             include_bm: whether to compute Sharpe ratio for benchmarks as well.
                 Defaults to True.
             compound_method: method to use when compounding return.
@@ -660,102 +564,83 @@ class ReturnSeries(TimeSeries):
             except KeyError:
                 raise ValueError(f"Risk free rate is not set: risk_free={risk_free}")
         elif isinstance(risk_free, float) or isinstance(risk_free, int):
-            rf = CashSeries.constant(risk_free, self.start, self.end)
+            try:
+                rf = self.risk_free[f"cash_{risk_free}"]
+            except KeyError:
+                rf = CashSeries.constant(risk_free, self.start, self.end)
+                self.add_rf(rf, f"cash_{risk_free}")
         else:
             raise TypeError(
-                "Risk free should be str, float, or int." f"received={type(risk_free)}"
+                "Risk free should be str, float, or 0." f"received={type(risk_free)}"
             )
 
         # create sharpe for main series
-        names = []
-        sharpe = []
-        start = []
-        end = []
-        risk_free = []
+        names, sharpe, start, end, risk_free = ([] for i in range(5))
 
+        # get column name of risk free rate
         rf_name = rf.series.columns[0]
 
-        # Make sure the start date is the max of start date of rf and returns,
-        # and end date is the min of end date of rf and returns
-        start_date = max(rf.start, self.start)
-        end_date = min(rf.end, self.end)
-
-        rf_use = copy.deepcopy(rf)
-        ret_use = copy.deepcopy(self)
-        rf_use.set_daterange(start_date, end_date)
-        ret_use.set_daterange(start_date, end_date)
-        series_name = ret_use.series.columns[0]
-
-        # compute excess return over rf rate
-        df = ret_use.series.merge(
-            rf_use.series, on="datetime", how="outer", sort=True
-        ).fillna(0)
-        df[series_name] -= df[rf_name]
-        df = df.drop(rf_name, axis="columns")
-
-        series = ReturnSeries(df)
-        ann_ret = series.get_annualized_return(method=compound_method)["value"][0]
-        ann_vol = series.get_annualized_volatility(
-            freq=freq, compound_method=compound_method
-        )["value"][0]
-        ratio = ann_ret / ann_vol
-
-        names.append(self.name)
-        sharpe.append(ratio)
-
-        if meta:
-            rf_ann = rf_use.get_annualized_return(method=compound_method)["value"][0]
-            rf_ann = f"{round(rf_ann*100, 2)}%"
-            start.append(series.start)
-            end.append(series.end)
-            risk_free.append(f"{rf_name}: {rf_ann}")
+        run_name = [self.name]
+        run_data = [self]
 
         if include_bm:
-            for name, benchmark in self.benchmark.items():
+            run_name += list(self.benchmark.keys())
+            run_data += list(self.benchmark.values())
 
-                try:
+        for name, series in zip(run_name, run_data):
 
-                    rf_use = copy.deepcopy(rf)
-                    benchmark = self._normalize_daterange(benchmark)
+            try:
 
-                    start_date = max(rf.start, benchmark.start)
-                    end_date = min(rf.end, benchmark.end)
+                # keep record of start and so they can be reset later
+                series_start = series.start
+                series_end = series.end
 
-                    rf_use.set_daterange(start_date, end_date)
-                    benchmark.set_daterange(start_date, end_date)
-                    bm_name = benchmark.series.columns[0]
+                # modify series so it's in the same timerange as the main series
+                self.align_daterange(series)
 
-                    df = benchmark.series.merge(
-                        rf_use.series, on="datetime", how="outer", sort=True
-                    ).fillna(0)
-                    df[bm_name] -= df[rf_name]
-                    df = df.drop(rf_name, axis="columns")
+                # get name of the series
+                name = series.series.columns[0]
 
-                    series = ReturnSeries(df)
-                    ann_ret = series.get_annualized_return(method=compound_method)[
+                # use the narrowest date range between series and risk free rate
+                start_date = max(rf.start, series.start)
+                end_date = min(rf.end, series.end)
+                rf.set_daterange(start_date, end_date)
+                series.set_daterange(start_date, end_date)
+
+                df = series.series.merge(
+                    rf.series, on="datetime", how="outer", sort=True
+                ).fillna(0)
+                df[name] -= df[rf_name]
+                df = df.drop(rf_name, axis="columns")
+
+                exccess_series = ReturnSeries(df)
+                ann_excess_ret = exccess_series.get_ann_ret(
+                    method=compound_method, include_bm=False
+                )["value"][0]
+                ann_series_vol = series.calc_ann_vol(
+                    freq=freq, compound_method=compound_method, include_bm=False
+                )["value"][0]
+                ratio = ann_excess_ret / ann_series_vol
+
+                names.append(name)
+                sharpe.append(ratio)
+
+                if meta:
+                    rf_ann = rf.get_ann_ret(method=compound_method, include_bm=False)[
                         "value"
                     ][0]
-                    ann_vol = series.get_annualized_volatility(
-                        freq=freq, compound_method=compound_method
-                    )["value"][0]
-                    ratio = ann_ret / ann_vol
+                    rf_ann = f"{round(rf_ann*100, 2)}%"
+                    risk_free.append(f"{rf_name}: {rf_ann}")
+                    start.append(series.start)
+                    end.append(series.end)
 
-                    names.append(name)
-                    sharpe.append(ratio)
+                series.set_daterange(series_start, series_end)
+                rf.reset()
 
-                    if meta:
-                        rf_ann = rf_use.get_annualized_return(method=compound_method)[
-                            "value"
-                        ][0]
-                        rf_ann = f"{round(rf_ann*100, 2)}%"
-                        start.append(series.start)
-                        end.append(series.end)
-                        risk_free.append(f"{rf_name}: {rf_ann}")
+            except Exception as e:  # pragma: no cover
 
-                except Exception as e:  # pragma: no cover
-
-                    log.error("Cannot compute sharpe ratio: " f"benchmark={name}: {e}")
-                    pass
+                log.error("Cannot compute sharpe ratio: " f"benchmark={name}: {e}")
+                pass
 
         if meta:
 
@@ -779,6 +664,127 @@ class ReturnSeries(TimeSeries):
 
         return result
 
+    def get_rolling_tot_ret(
+        self,
+        window: Optional[int] = 36,
+        freq: Optional[str] = "M",
+        include_bm: Optional[bool] = True,
+        method: Optional[str] = "geometric",
+    ) -> Dict[str, pd.DataFrame]:
+        """Computes rolling total return of the series
+
+        Args:
+            window: the rolling window. Defaults to 36.
+            freq: frequency of the series. Defaults to "M".
+            include_bm: whether to compute rolling total return for
+                benchmarks as well. Defaults to True.
+            method: method to use when compounding total return.
+                Defaults to "geometric".
+
+
+        Returns:
+            Dict[pd.DataFrame]: dictionary of rolling total returns
+
+                * key: name of the series
+                * value: rolling total returns, in a datetime indexed pandas dataframe
+        """
+
+        # Store result in dictionary
+        result = dict()
+
+        # Columns in the returned dataframe
+        run_name = [self.name]
+        run_data = [self]
+
+        if include_bm:
+            run_name += list(self.benchmark.keys())
+            run_data += list(self.benchmark.values())
+
+        for name, series in zip(run_name, run_data):
+
+            # keep record of start and so they can be reset later
+            series_start = series.start
+            series_end = series.end
+
+            # modify series so it's in the same timerange as the main series
+            self.align_daterange(series)
+
+            # compute rolling total return
+            ret = series.to_period(freq=freq, method=method)
+            roll_result = ret.rolling(window).apply(compound(method))
+            roll_result = roll_result.dropna()
+
+            # store result in dictionary
+            result[name] = roll_result
+
+            # reset series date range
+            series.set_daterange(series_start, series_end)
+
+        return result
+
+    def get_rolling_ann_vol(
+        self,
+        window: Optional[int] = 36,
+        freq: Optional[str] = "M",
+        method: Optional[str] = "sample",
+        include_bm: Optional[bool] = True,
+        compound_method: Optional[str] = "geometric",
+    ) -> Dict[str, pd.DataFrame]:
+        """Computes rolling volatility (standard deviation) of the series
+
+        Args:
+            window: the rolling window. Defaults to 36.
+            freq: Returns are converted to the same frequency before volatility
+                is compuated. Defaults to "M".
+            method: {'sample', 'population'}. method used to compute volatility
+                (standard deviation). Defaults to "sample".
+            include_bm: whether to compute rolling volatility for
+                benchmarks as well. Defaults to True.
+            compound_method: method to use when compounding return.
+                Defaults to "geometric".
+
+        Returns:
+            Dict[pd.DataFrame]: dictionary of rolling total returns
+
+                * key: name of the series
+                * value: rolling total returns, in a datetime indexed pandas dataframe
+        """
+
+        # Store result in dictionary
+        result = dict()
+
+        # Columns in the returned dataframe
+        run_name = [self.name]
+        run_data = [self]
+
+        if include_bm:
+            run_name += list(self.benchmark.keys())
+            run_data += list(self.benchmark.values())
+
+        for name, series in zip(run_name, run_data):
+
+            # keep record of start and so they can be reset later
+            series_start = series.start
+            series_end = series.end
+
+            # modify series so it's in the same timerange as the main series
+            self.align_daterange(series)
+
+            # compute rolling total return
+            ret = series.to_period(freq=freq, method=compound_method)
+            roll_result = ret.rolling(window).apply(
+                lambda x: calc_ann_vol(x, method=method)
+            )
+            roll_result = roll_result.dropna()
+
+            # store result in dictionary
+            result[name] = roll_result
+
+            # reset series date range
+            series.set_daterange(series_start, series_end)
+
+        return result
+
 
 class CashSeries(ReturnSeries):
     @classmethod
@@ -788,7 +794,7 @@ class CashSeries(ReturnSeries):
         start: Optional[str] = "1980-01-01",
         end: Optional[str] = "2029-12-31",
     ):
-        """Create a constant cash daily returns stream
+        """Creates a constant cash daily returns stream
 
         Args:
             annualized_return: Annualized return of the cash, in decimals.
@@ -818,7 +824,7 @@ class CashSeries(ReturnSeries):
 
     @classmethod
     def read_fred_libor_1m(cls):
-        """Create one month libor daily returns from fred data
+        """Creates one month libor daily returns from fred data
 
         Returns:
             pyform.CashSeries: one month libor daily returns
